==> MafDb.ESP6500SI.V2.SSA137_3.1.0.tar.gz: MafDb.ESP6500SI.V2.SSA137/inst/MafDbPkgTemplate/man/makeMafDbPackage.Rd <==
\name{makeMafDbPackageESP}
\alias{makeMafDbPackageESP}
\alias{MafDbESPdefaultURL}
\alias{MafDbESPdefaultPkgName}

\title{
Make a MafDb annotation data package from the NHLBI GO ESP Project
}
\description{
 This function creates an annotation data package for a MafDb object. Its primary purpose is to
 ease the task of fetching and packaging newer minimum allele frequency (MAF) data. Note that
 MAF values are processed and stored in a way to reduce their space in disk. Please consult the
 manual page for the \code{\link[VariantFiltering]{MafDb-class}} to know the details of these
 processing steps.
}
\usage{
makeMafDbPackageESP(destDir=path.expand("~"), MafDbURL=MafDbESPdefaultURL, MafDbPkgName=MafDbESPdefaultPkgName,
                    genome="hg19", version=NULL, author=NULL, maintainer=NULL, license=NULL, yieldSize=1000000)

}
\arguments{
  \item{destDir}{Destination directory for the newly created package.}
  \item{MafDbURL}{URL to the source VCF file(s). By default, it points to the URL holding the data currently stored in the package that defines this function.}
  \item{MafDbPkgName}{Name of the newly created package. This will define as well the name of the exported MafDb object.}
  \item{genome}{Version of the human genome, following UCSC nomenclature. Necessary for the internal call to the \code{readVcf()} function from the \code{VariantAnnotation} package.}
  \item{version}{Version to put on the new package. By default, the version corresponds to the version of the package that defines this function, bumping the second version number.}
  \item{author}{Author to put on the new package. By default, the author corresponds to the author of the package that defines this function.}
  \item{maintainer}{Maintainer to put on the new package. By default, the maintainer corresponds to the maintainer of the package that defines this function.}
  \item{license}{License to put on the new package. By default, the license corresponds to the license of the package that defines this function.}
  \item{yieldSize}{In the case source tabix VCF files, they are not read at once, but scanned in batches whose size is determined by this argument. By default is set to one million variants but it may be reduced to lower main memory requirements.}
}
\value{
Path to the folder containing the created data package.
}
\author{
 R. Castelo
}
\seealso{
  \code{\link[VariantFiltering]{MafDb-class}}
  \code{\link[VariantFiltering]{snpid2maf}}
  \code{\link{MafDb.ESP6500SI.V2.SSA137}}
}
\examples{
MafDbESPdefaultURL ## default URL from where makeMafDbPackageESP() fetches the MAF data

MafDbESPdefaultPkgName ## default name for the package that makeMafDbPackageESP() creates

\dontrun{
## the previous two default values can be overridden when calling makeMafDbPackageESP()
makeMafDbPackageESP()
}
}
\keyword{utilities}

==> MafDb.ESP6500SI.V2.SSA137_3.2.0.tar.gz: MafDb.ESP6500SI.V2.SSA137/inst/MafDbPkgTemplate/man/makeMafDbPackage.Rd <==
\name{makeMafDbPackageESP}
\alias{makeMafDbPackageESP}
\alias{MafDbESPdefaultURL}
\alias{MafDbESPdefaultPkgName}

\title{
Make a MafDb annotation data package from the NHLBI GO ESP Project
}
\description{
 This function creates an annotation data package for a MafDb object. Its primary purpose is to
 ease the task of fetching and packaging newer minor allele frequency (MAF) data. Note that
 MAF values are processed and stored in a way to reduce their space in disk. Please consult the
 manual page for the \code{\link[VariantFiltering]{MafDb-class}} to know the details of these
 processing steps.
}
\usage{
makeMafDbPackageESP(destDir=path.expand("~"), MafDbURL=MafDbESPdefaultURL, MafDbPkgName=MafDbESPdefaultPkgName,
                    genome="hg19", version=NULL, author=NULL, maintainer=NULL, license=NULL, yieldSize=1000000)

}
\arguments{
  \item{destDir}{Destination directory for the newly created package.}
  \item{MafDbURL}{URL to the source VCF file(s). By default, it points to the URL holding the data currently stored in the package that defines this function.}
  \item{MafDbPkgName}{Name of the newly created package. This will define as well the name of the exported MafDb object.}
  \item{genome}{Version of the human genome, following UCSC nomenclature. Necessary for the internal call to the \code{readVcf()} function from the \code{VariantAnnotation} package.}
  \item{version}{Version to put on the new package. By default, the version corresponds to the version of the package that defines this function, bumping the second version number.}
  \item{author}{Author to put on the new package. By default, the author corresponds to the author of the package that defines this function.}
  \item{maintainer}{Maintainer to put on the new package. By default, the maintainer corresponds to the maintainer of the package that defines this function.}
  \item{license}{License to put on the new package. By default, the license corresponds to the license of the package that defines this function.}
  \item{yieldSize}{In the case source tabix VCF files, they are not read at once, but scanned in batches whose size is determined by this argument. By default is set to one million variants but it may be reduced to lower main memory requirements.}
}
\value{
Path to the folder containing the created data package.
}
\author{
 R. Castelo
}
\seealso{
  \code{\link[VariantFiltering]{MafDb-class}}
  \code{\link[VariantFiltering]{snpid2maf}}
  \code{\link{MafDb.ESP6500SI.V2.SSA137}}
}
\examples{
MafDbESPdefaultURL ## default URL from where makeMafDbPackageESP() fetches the MAF data

MafDbESPdefaultPkgName ## default name for the package that makeMafDbPackageESP() creates

\dontrun{
## the previous two default values can be overridden when calling makeMafDbPackageESP()
makeMafDbPackageESP()
}
}
\keyword{utilities}
